@@ -23,22 +23,32 @@
 #include <memory>
 #include <mutex>
 
+#include <krunner_version.h>
 #include <KRunner/AbstractRunner>
+#if KRUNNER_VERSION_MAJOR >= 6
+#define KRUNNS KRunner
+#else
+#define KRUNNS Plasma
+#endif
 
 class RclConfig;
 namespace Rcl {
 class Db;
 }
 
-class RecollRunner : public Plasma::AbstractRunner
+class RecollRunner : public KRUNNS::AbstractRunner
 {
     Q_OBJECT
 
 public:
+#if KRUNNER_VERSION_MAJOR >= 6
+    RecollRunner(QObject *parent, const KPluginMetaData &data);
+#else
     RecollRunner(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
 
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
+    void match(KRUNNS::RunnerContext &context) override;
+    void run(const KRUNNS::RunnerContext &context, const KRUNNS::QueryMatch &match) override;
     void reloadConfiguration() override;
 
 protected:
