@@ -325,6 +325,19 @@ void RclMain::init()
     periodictimer->start(1000);
     setUIPrefs();
     reslist->resetList();
+
+#ifdef RCL_SHOW_FOCUS_CHANGES
+    // Help with understanding where the focus goes... The focus order should probably be
+    // explicitely set with QWidget::setTabOrder().
+    connect(qApp, &QApplication::focusChanged,
+            [this](QWidget *oldWidget, QWidget *newWidget) {
+              QString msg("Focus changed from: ");
+              msg += oldWidget ? oldWidget->objectName() : QString("(none)");
+              msg += " to ";
+              msg += newWidget ? newWidget->objectName() : QString("(none)");
+              this->statusBar()->showMessage(msg, 2000);
+            });
+#endif
 }
 
 void RclMain::onSSearchTypeChanged(int typ)
@@ -386,6 +399,8 @@ void RclMain::onNewShortcuts()
             disconnect(m_focustotablesc, SIGNAL(activated()), restable, SLOT(takeFocus()));
         }
     }
+    SETSHORTCUT(this, "main:389", tr("Main Window"), tr("Show advanced search dialog"),
+                "Alt+s", m_showadvsearchsc, showAdvSearchDialog);
 }
 
 void RclMain::setupToolbars()
