@@ -136,17 +136,6 @@ int DocSequenceDb::getFirstMatchPage(Rcl::Doc &doc, string& term)
     return -1;
 }
 
-int DocSequenceDb::getFirstMatchLine(const Rcl::Doc &doc, const string& term)
-{
-    std::unique_lock<std::mutex> locker(o_dblock);
-    if (!setQuery())
-        return false;
-    if (m_q->whatDb()) {
-        return m_q->getFirstMatchLine(doc, term);
-    }
-    return 1;
-}
-
 list<string> DocSequenceDb::expand(Rcl::Doc &doc)
 {
     std::unique_lock<std::mutex> locker(o_dblock);
@@ -241,6 +230,11 @@ bool DocSequenceDb::setQuery()
     return m_lastSQStatus;
 }
 
+void DocSequenceDb::setqquantum(int q)
+{
+    if (m_q)
+        m_q->setqquantum(q);
+}
 bool DocSequenceDb::docDups(const Rcl::Doc& doc, std::vector<Rcl::Doc>& dups)
 {
     if (m_q->whatDb()) {
