@@ -37,8 +37,9 @@ public:
     virtual bool getDoc(int num, Rcl::Doc &doc, std::string * = nullptr) override;
     virtual int getResCnt() override;
     virtual void getTerms(HighlightData& hld) override;
-    virtual void getDocTerms(const Rcl::Doc& doc, std::vector<std::vector<std::string>>& terms) override;
-
+    virtual void getDocTerms(
+        const Rcl::Doc& doc, std::vector<std::vector<std::string>>& terms) override;
+    virtual void setqquantum(int q) override;
     // Called to fill-up the snippets window. Ignoers
     // buildabstract/replaceabstract and syntabslen
     virtual bool getAbstract(Rcl::Doc &doc, PlainToRich *ptr, std::vector<Rcl::Snippet>&,
@@ -47,7 +48,6 @@ public:
     virtual bool getAbstract(Rcl::Doc &doc, PlainToRich *ptr, std::vector<std::string>&,
                              bool forcesnips) override;
     virtual int getFirstMatchPage(Rcl::Doc&, std::string& term) override;
-    virtual int getFirstMatchLine(const Rcl::Doc&, const std::string& term) override;
     virtual bool docDups(const Rcl::Doc& doc, std::vector<Rcl::Doc>& dups)
         override;
     virtual std::string getDescription() override;
