@@ -28,10 +28,12 @@
 #include <vector>
 #include <ostream>
 #include <memory>
+#include <set>
 
 #include "rcldb.h"
 #include "smallut.h"
 #include "hldata.h"
+#include "rclutil.h"
 
 class RclConfig;
 class AdvSearch;
@@ -47,33 +49,32 @@ enum SClType {
 
 class SearchDataClause;
 class SearchDataClauseDist;
+class SdataWalker;
 
 /** 
-    A SearchData object represents a Recoll user query, for translation
-    into a Xapian query tree. This could probably better called a 'question'.
+    A SearchData object represents a Recoll user query, to be translated into a Xapian query
+    tree. This could probably better called a 'question'.
 
-    This is a list of SearchDataClause objects combined through either
+    This is a mostly a list of SearchDataClause objects (possibly sublists) combined through either
     OR or AND.
 
-    Clauses either reflect user entry in a query field: some text, a
-    clause type (AND/OR/NEAR etc.), possibly a distance, or are the
-    result of parsing query language input. A clause can also point to
-    another SearchData representing a subquery.
+    Clauses either reflect user entry in a query field: some raw text, a clause type (AND/OR/NEAR
+    etc.), possibly a distance, or are the result of parsing query language input. A clause can also
+    point to another SearchData representing a subquery.
 
-    The content of each clause when added may not be fully parsed yet
-    (may come directly from a gui field). It will be parsed and may be
-    translated to several queries in the Xapian sense, for example
-    several terms and phrases as would result from 
-    ["this is a phrase"  term1 term2] . 
+    The content of each clause when added may not be fully parsed yet (e.g. may come directly from a
+    GUI field). It will be parsed and may be translated to several queries in the Xapian sense, for
+    example several terms and phrases as would result from ["this is a phrase" term1 term2] .
 
-    This is why the clauses also have an AND/OR/... type. They are an 
-    intermediate form between the primary user input and 
-    the final Xapian::Query tree.
+    This is why the clauses also have an AND/OR/... type. They are an intermediate form between the
+    primary user input and the final Xapian::Query tree.
 
-    For example, a phrase clause could be added either explicitly or
-    using double quotes: {SCLT_PHRASE, [this is a phrase]} or as
-    {SCLT_XXX, ["this is a phrase"]}
+    For example, a phrase clause could be added either explicitly or using double quotes:
+    {SCLT_PHRASE, [this is a phrase]} or as {SCLT_XXX, ["this is a phrase"]}
 
+    For natural text clauses (not file names or value range queries), the first step in the
+    processing towards the Xapian query always transforms the text into possible index terms:
+    capitals and diacritics stripped or not, depending on the index type.
 */
 class SearchData {
 public:
@@ -153,9 +154,35 @@ public:
     std::string getDescription() {return m_description;}
     void setDescription(const std::string& d) {m_description = d;}
 
-    /** Return an XML version of the contents, for storage in search history
-        by the GUI */
+    /** Return an XML version of the contents (e.g. for storage in search history by the GUI)
+     * 
+     * <SD>                         <!-- Search Data -->
+     *  <CL>                        <!-- Clause List -->
+     *    <CLT>AND|OR</CLT>         <!-- conjunction AND is default, ommitted -->
+     *    <C>                       <!-- Clause -->
+     *     [<NEG/>]                 <!-- Possible negation -->
+     *     <CT>AND|OR|FN|PH|NE</CT> <!-- Clause type -->
+     *     <F>[base64data]</F>      <!-- Optional base64-encoded field name -->
+     *     <T>[base64data]</T>      <!-- base64-encoded text -->
+     *     <S>slack</S>             <!-- optional slack for near/phrase -->
+     *    </C>
+     *
+     *    <ND>[base64 path]</ND>    <!-- Path exclusion -->
+     *    <YD>[base64 path]</YD>    <!-- Path filter -->
+     *  </CL>
+     * 
+     *  <DMI><D>1</D><M>6</M><Y>2014</Y></DMI> <--! datemin -->
+     *  <DMA><D>30</D><M>6</M><Y>2014</Y></DMA> <--! datemax -->
+     *  <MIS>minsize</MIS>          <!-- Min size -->
+     *  <MAS>maxsize</MAS>          <!-- Max size -->
+     *  <ST>space-sep mtypes</ST>   <!-- Included mime types -->
+     *  <IT>space-sep mtypes</IT>   <!-- Excluded mime types -->
+     *
+     * </SD>
+     */
     std::string asXML();
+    /** Convert back the XML to SearchData */
+    static std::shared_ptr<Rcl::SearchData> fromXML(const std::string& xml, bool verbose = true);
 
     void setTp(SClType tp) {
         m_tp = tp;
@@ -164,7 +191,14 @@ public:
     SClType getTp() {
         return m_tp;
     }
-    
+
+    void setNoWildExp(bool x) {
+        m_nowildexp = x;
+    }
+    bool getNoWildExp() {
+        return m_nowildexp;
+    }
+
     void setMaxExpand(int max) {
         m_softmaxexpand = max;
     }
@@ -173,10 +207,17 @@ public:
     int getMaxExp() {return m_maxexp;}
     int getMaxCl() {return m_maxcl;}
     int getSoftMaxExp() {return m_softmaxexpand;}
-    void dump(std::ostream& o) const;
+
+    // Recursively dump the tree to o
+    void rdump(std::ostream& o, bool asxml=false);
+
+    // Print out my data only
+    void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const;
+    void closeDump(std::ostream& o, const std::string& tabs, bool asxml=false) const;
 
     friend class ::AdvSearch;
-
+    friend bool sdataWalk(SearchData*, SdataWalker&);
+    
 private:
     // Combine type. Only SCLT_AND or SCLT_OR here
     SClType                   m_tp; 
@@ -203,6 +244,8 @@ private:
     int64_t        m_minSize{-1};
     // Filtering for subdocs: -1:any, 0: only free-standing, 1: only subdocs
     int            m_subspec{SUBDOC_ANY};
+
+    bool           m_nowildexp{false};
     
     // Printable expanded version of the complete query, retrieved/set
     // from rcldb after the Xapian::setQuery() call
@@ -246,10 +289,11 @@ public:
                    SDCM_NOSYNS = 0x40, // Don't perform synonym expansion
                    // Aargh special case. pathelts are case/diac-sensitive
                    // even in a stripped index
-                   SDCM_PATHELT = 0x80, 
+                   SDCM_PATHELT = 0x80,
                    SDCM_FILTER = 0x100,
                    // Terms inside phrases are not expanded if this is not set (by 'x' modifier)
-                   SDCM_EXPANDPHRASE = 0x200, 
+                   SDCM_EXPANDPHRASE = 0x200,
+                   SDCM_NOWILDEXP = 0x400,
     };
     enum Relation {REL_CONTAINS, REL_EQUALS, REL_LT, REL_LTE, REL_GT, REL_GTE};
 
@@ -286,6 +330,11 @@ public:
     bool getAutoCase() {
         return m_parentSearch ? m_parentSearch->getAutoCase() : true;
     }
+    bool getNoWildExp() {
+        if (m_modifiers & SDCM_NOWILDEXP)
+            return true;
+        return m_parentSearch ? m_parentSearch->getNoWildExp() : false;
+    }
     int getMaxExp() {
         return m_parentSearch ? m_parentSearch->getMaxExp() : 10000;
     }
@@ -316,7 +365,7 @@ public:
     virtual Relation getrel() {
         return m_rel;
     }
-    virtual void dump(std::ostream& o) const;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const;
 
     friend class SearchData;
 protected:
@@ -366,8 +415,9 @@ public:
     virtual void setfield(const std::string& field) {
         m_field = field;
     }
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
 
+    friend class SearchDataVisitor;
 protected:
     std::string  m_text;  // Raw user entry text.
     std::string  m_field; // Field specification if any
@@ -376,7 +426,7 @@ protected:
     size_t  m_curcl;
 
     bool processUserString(Rcl::Db &db, const std::string &iq,
-                           std::string &ermsg,
+                           std::string &ermsg, std::string& pbterm,
                            void* pq, int slack = 0, bool useNear = false);
     bool expandTerm(Rcl::Db &db, std::string& ermsg, int mods, 
                     const std::string& term, 
@@ -411,7 +461,7 @@ public:
         return new SearchDataClauseRange(*this);
     }
 
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
     virtual const std::string& gettext2() const {
         return m_t2;
     }
@@ -444,7 +494,7 @@ public:
     }
 
     virtual bool toNativeQuery(Rcl::Db &, void *) override;
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
 };
 
 
@@ -482,7 +532,7 @@ public:
     }
 
     virtual bool toNativeQuery(Rcl::Db &, void *) override;
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
 };
 
 /** 
@@ -506,7 +556,7 @@ public:
     virtual void setslack(int slack) {
         m_slack = slack;
     }
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
 private:
     int m_slack;
 };
@@ -535,12 +585,25 @@ public:
     virtual std::shared_ptr<SearchData> getSub() {
         return m_sub;
     }
-    virtual void dump(std::ostream& o) const override;
+    virtual void dump(std::ostream& o, const std::string& tabs, bool asxml=false) const override;
 
 protected:
     std::shared_ptr<SearchData> m_sub;
 };
 
+class SdataWalker {
+public:
+    virtual ~SdataWalker() {};
+    virtual bool clause(SearchDataClause*) {
+        return true;
+    }
+    virtual bool sdata(SearchData*, bool) {
+        return true;
+    }
+};
+
+bool sdataWalk(SearchData* top, SdataWalker& walker);
+
 } // Namespace Rcl
 
 #endif /* _SEARCHDATA_H_INCLUDED_ */
