@@ -1,4 +1,4 @@
-/* Copyright (C) 2004-2023 J.F.Dockes 
+/* Copyright (C) 2004-2025 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -15,13 +15,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "autoconfig.h"
-
 #include <string>
 #include <vector>
+#include <iostream>
 
-#include <ctype.h>
-#include <stdio.h>
 #include <ctype.h>
 #include <time.h>
 #include <cstdlib>
@@ -31,16 +28,25 @@
 #include "base64.h"
 #include "transcode.h"
 #include "smallut.h"
+#include "log.h"
 
 using namespace std;
 
 //#define DEBUG_MIMEPARSE 
 #ifdef DEBUG_MIMEPARSE
-#define DPRINT(X) fprintf X
+#define DPRINT(X) LOGERR(X)
 #else
 #define DPRINT(X)
 #endif
 
+//#define DEBUGDATE
+#ifdef DEBUGDATE
+#include "log.h"
+#define DATEDEB(X) LOGDEB(X)
+#else
+#define DATEDEB(X)
+#endif
+
 // Parsing a header value. Only content-type and content-disposition
 // have parameters, but others are compatible with content-type
 // syntax, only, parameters are not used. So we can parse all like:
@@ -56,16 +62,16 @@ using namespace std;
 
 
 
-/** Decode a MIME parameter value encoded according to rfc2231
+/** Decode a MIME parameter value encoded according to rfc2231. The input has already been processed
+ *  for continuations, we just process the %-encoding and transcoding to UTF-8
  *
- * Example input withs input charset == "":  
- *     [iso-8859-1'french'RE%A0%3A_Smoke_Tests%20bla]
- * Or (if charset is set) : RE%A0%3A_Smoke_Tests%20bla
+ * Example input with @param charset == "":  [iso-8859-1'french'RE%A0%3A_Smoke_Tests%20bla]
+ *   Or if charset is set: RE%A0%3A_Smoke_Tests%20bla
  *
  * @param in input string, ascii with rfc2231 markup
  * @param out output string
- * @param charset if empty: decode string like 'charset'lang'more%20stuff,
- *      else just do the %XX part
+ * @param charset if empty: extract charset from input like 'charset'lang'more%20stuff,
+ *  the input just has the %XX part
  * @return out output string encoded in utf-8
  */
 bool rfc2231_decode(const string &in, string &out, string &charset)
@@ -76,20 +82,19 @@ bool rfc2231_decode(const string &in, string &out, string &charset)
         if ((pos1 = in.find("'")) == string::npos)
             return false;
         charset = in.substr(0, pos1);
-        // fprintf(stderr, "Charset: [%s]\n", charset.c_str());
+        LOGDEB1("Charset: [" << charset << "\n");
         pos1++;
 
         if ((pos2 = in.find("'", pos1)) == string::npos)
             return false;
         // We have no use for lang for now
         // string lang = in.substr(pos1, pos2-pos1); 
-        // fprintf(stderr, "Lang: [%s]\n", lang.c_str());
+        LOGDEB1("Lang: [" << lang << "\n");
         pos2++;
     }
 
     string raw;
     qp_decode(in.substr(pos2), raw, '%');
-    // fprintf(stderr, "raw [%s]\n", raw.c_str());
     if (!transcode(raw, out, charset, cstr_utf8))
         return false;
     return true;
@@ -112,8 +117,7 @@ public:
 };
 
 // Skip mime comment. This must be called with in[start] == '('
-static string::size_type 
-skip_comment(const string &in, string::size_type start, Lexical &lex)
+static string::size_type skip_comment(const string &in, string::size_type start, Lexical &lex)
 {
     int commentlevel = 0;
     for (; start < in.size(); start++) {
@@ -130,8 +134,10 @@ skip_comment(const string &in, string::size_type start, Lexical &lex)
         if (in[start] == '(')
             commentlevel++;
         if (in[start] == ')') {
-            if (--commentlevel == 0)
+            if (--commentlevel == 0) {
+                ++start;
                 break;
+            }
         }
     }
     if (start == in.size() && commentlevel != 0) {
@@ -143,8 +149,7 @@ skip_comment(const string &in, string::size_type start, Lexical &lex)
 
 // Skip initial whitespace and (possibly nested) comments. 
 static string::size_type 
-skip_whitespace_and_comment(const string &in, string::size_type start, 
-                            Lexical &lex)
+skip_whitespace_and_comment(const string &in, string::size_type start, Lexical &lex)
 {
     while (1) {
         if ((start = in.find_first_not_of(" \t\r\n", start)) == string::npos)
@@ -166,14 +171,16 @@ skip_whitespace_and_comment(const string &in, string::size_type start,
 /// @param lex  the returned token and its description
 /// @param delims separators we should look for
 static string::size_type 
-find_next_token(const string &in, string::size_type start, 
-                Lexical &lex, string delims = ";=")
+find_next_token(const string &in, string::size_type start, Lexical &lex, string delims = ";=")
 {
     char oquot, cquot;
 
     start = skip_whitespace_and_comment(in, start, lex);
-    if (start == string::npos || start == in.size())
+    if (start == string::npos || start == in.size()) {
+        lex.what = Lexical::token;
+        lex.value.clear();
         return in.size();
+    }
 
     // Begins with separator ? return it.
     string::size_type delimi = delims.find_first_of(in[start]);
@@ -242,12 +249,6 @@ public:
     vector<Chunk> chunks;
 };
 
-void stringtolower(string &out, const string& in)
-{
-    for (string::size_type i = 0; i < in.size(); i++)
-        out.append(1, char(tolower(in[i])));
-}
-
 // Parse MIME field value. Should look like:
 //  somevalue ; param1=val1;param2=val2
 bool parseMimeHeaderValue(const string& value, MimeHeaderValue& parsed)
@@ -260,57 +261,77 @@ bool parseMimeHeaderValue(const string& value, MimeHeaderValue& parsed)
 
     // Get the field value
     start = find_next_token(value, start, lex);
-    if (start == string::npos || lex.what != Lexical::token) 
+    LOGDEB1("lex.what " << lex.what << " lex.value [" << lex.value << "] start " << start << "\n");
+    if (start == string::npos)
         return false;
-    parsed.value = lex.value;
+    if  (lex.what == Lexical::separator && lex.value == ";") {
+        // Ok, empty value
+    } else if (lex.what == Lexical::token) {
+        parsed.value = lex.value;
+    } else {
+        return false;
+    }
 
     map<string, string> rawparams;
     // Look for parameters
     for (;;) {
+        if (start >= value.size()) {
+            break;
+        }
         string paramname, paramvalue;
         lex.reset();
         start = find_next_token(value, start, lex);
-        if (start == value.size())
-            break;
         if (start == string::npos) {
-            //fprintf(stderr, "Find_next_token error(1)\n");
+            LOGDEB1("Find_next_token error(1)\n");
             return false;
         }
         if (lex.what == Lexical::separator && lex.value[0] == ';')
             continue;
         if (lex.what != Lexical::token) 
             return false;
-        stringtolower(paramname, lex.value);
-
-        start = find_next_token(value, start, lex);
-        if (start == string::npos || lex.what != Lexical::separator || 
-            lex.value[0] != '=') {
-            //fprintf(stderr, "Find_next_token error (2)\n");
-            return false;
+        paramname = stringtolower((const std::string&)lex.value);
+        // EOD with just param name
+        if (start >= value.size()) {
+            rawparams[paramname] = "";
+            break;
         }
 
+        start = find_next_token(value, start, lex);
+        if (start == string::npos) {
+            LOGDEB1("Find_next_token error (2)\n");
+            return false;
+        }
+        if (lex.what == Lexical::separator && (lex.value.empty() || lex.value[0] == ';')) {
+            // Parameter with no value, process as null value
+            rawparams[paramname] = "";
+            continue;
+        } else if (lex.what == Lexical::separator && lex.value[0] == '=') {
+            // Normal
+        } else {
+            LOGDEB1("Find_next_token error (3)\n");
+            return false;
+        }
+            
         start = find_next_token(value, start, lex);
         if (start == string::npos || lex.what != Lexical::token) {
-            //fprintf(stderr, "Parameter has no value!");
+            LOGDEB1("Parameter has no value!");
             return false;
         }
         paramvalue = lex.value;
         rawparams[paramname] = paramvalue;
-        //fprintf(stderr, "RAW: name [%s], value [%s]\n", paramname.c_str(),
-        //              paramvalue.c_str());
+        LOGDEB1("RAW: name [" << paramname << "] value [" << paramvalue << "]\n");
     }
-    //    fprintf(stderr, "Number of raw params %d\n", rawparams.size());
+    LOGDEB1("Number of raw params " << rawparams.size() << '\n');
 
     // RFC2231 handling: 
     // - if a parameter name ends in * it must be decoded 
     // - If a parameter name looks line name*ii[*] it is a
     //   partial value, and must be concatenated with other such.
     
-    map<string, Chunks> chunks;
-    for (map<string, string>::const_iterator it = rawparams.begin(); 
-         it != rawparams.end(); it++) {
-        string nm = it->first;
-        //      fprintf(stderr, "NM: [%s]\n", nm.c_str());
+    map<string, Chunks> allchunks;
+    for (const auto& [rawnm, rawvalue] : rawparams) {
+        string nm = rawnm;
+        LOGDEB1("NM: [" << nm << "]\n")
         if (nm.empty()) // ??
             continue;
 
@@ -320,57 +341,50 @@ bool parseMimeHeaderValue(const string& value, MimeHeaderValue& parsed)
             chunk.decode = true;
         } else
             chunk.decode = false;
-        //      fprintf(stderr, "NM1: [%s]\n", nm.c_str());
+        LOGDEB1("NM1: [" << nm << "]\n");
 
-        chunk.value = it->second;
+        chunk.value = rawvalue;
 
         // Look for another asterisk in nm. If none, assign index 0
         string::size_type aster;
         int idx = 0;
         if ((aster = nm.rfind("*")) != string::npos) {
             string num = nm.substr(aster+1);
-            //fprintf(stderr, "NUM: [%s]\n", num.c_str());
+            LOGDEB1("NUM: [" << num << "]\n");
             nm.erase(aster);
             idx = atoi(num.c_str());
         }
         Chunks empty;
-        if (chunks.find(nm) == chunks.end())
-            chunks[nm] = empty;
-        chunks[nm].chunks.resize(idx+1);
-        chunks[nm].chunks[idx] = chunk;
-        //fprintf(stderr, "CHNKS: nm [%s], idx %d, decode %d, value [%s]\n", 
-        // nm.c_str(), idx, int(chunk.decode), chunk.value.c_str());
+        if (allchunks.find(nm) == allchunks.end())
+            allchunks[nm] = empty;
+        allchunks[nm].chunks.resize(idx+1);
+        allchunks[nm].chunks[idx] = chunk;
+        LOGDEB1("CHNKS: nm [" << nm << "] idx " << idx << " decode " << chunk.decode << " value [" <<
+               chunk.value << "]\n");
     }
 
-    // For each parameter name, concatenate its chunks and possibly
-    // decode Note that we pass the whole concatenated string to
-    // decoding if the first chunk indicates that decoding is needed,
-    // which is not right because there might be uncoded chunks
-    // according to the rfc.
-    for (map<string, Chunks>::const_iterator it = chunks.begin(); 
-         it != chunks.end(); it++) {
-        if (it->second.chunks.empty())
+    // For each parameter name, concatenate its chunks and possibly decode Note that we pass the
+    // whole concatenated string to decoding if the first chunk indicates that decoding is needed,
+    // which is not right because there might be uncoded chunks according to the rfc.
+    for (const auto& [nm, chunks] : allchunks) {
+        if (chunks.chunks.empty())
             continue;
-        string nm = it->first;
         // Create the name entry
         if (parsed.params.find(nm) == parsed.params.end())
             parsed.params[nm].clear();
-        // Concatenate all chunks and decode the whole if the first one needs
-        // to. Yes, this is not quite right.
+        // Concatenate all chunks and decode the whole if indicated by the first one.
         string value;
-        for (vector<Chunk>::const_iterator vi = it->second.chunks.begin();
-             vi != it->second.chunks.end(); vi++) {
-            value += vi->value;
+        for (const auto& chunk : chunks.chunks) {
+            value += chunk.value;
         }
-        if (it->second.chunks[0].decode) {
+        if (chunks.chunks[0].decode) {
             string charset;
             rfc2231_decode(value, parsed.params[nm], charset);
         } else {
             // rfc2047 MUST NOT but IS used by some agents
             rfc2047_decode(value, parsed.params[nm]);
         }
-        //fprintf(stderr, "FINAL: nm [%s], value [%s]\n", 
-        //nm.c_str(), parsed.params[nm].c_str());
+        LOGDEB1("FINAL: nm [" << nm << "] value [" << parsed.params[nm] << "]\n");
     }
     
     return true;
@@ -423,21 +437,33 @@ bool qp_decode(const string& in, string &out, char esc)
     return true;
 }
 
-// Decode an word encoded as quoted printable or base 64
-static bool rfc2047_decodeParsed(const std::string& charset, 
-                                 const std::string& encoding, 
-                                 const std::string& value, 
-                                 std::string &utf8)
+// We should get ASCII data in, but give a try at decoding from UTF-8 because some buggy agents
+// (esp. news/RSS) send such headers. If this fails, decode from CP1252, ASCII superset guaranteed
+// to succeed.
+static void utf8OrCp1252(const std::string& in, std::string& utf8)
 {
-    DPRINT((stderr, "DecodeParsed: charset [%s] enc [%s] val [%s]\n",
-            charset.c_str(), encoding.c_str(), value.c_str()));
+    utf8.clear();
+    int ecnt;
+    if (!transcode(in, utf8, cstr_utf8, cstr_utf8, &ecnt) || ecnt != 0) {
+        utf8.clear();
+        transcode(in, utf8, "CP1252", cstr_utf8);
+    }
+}
+
+// Decode an word encoded as quoted printable or base 64
+static bool rfc2047_decodeParsed(const std::string& charset, const std::string& encoding,
+                                 const std::string& value, std::string &utf8)
+{
+    DPRINT("rfc2047_decodeParsed: charset [" << charset << " enc [" << encoding <<
+           "] val [" << value << "]\n");
+
     utf8.clear();
 
     string decoded;
     if (!stringlowercmp("b", encoding)) {
         if (!base64_decode(value, decoded))
             return false;
-        DPRINT((stderr, "FromB64: [%s]\n", decoded.c_str()));
+        DPRINT("rfc2047_decodeParsed: fromB64: [" << decoded << "]\n");
     } else if (!stringlowercmp("q", encoding)) {
         if (!qp_decode(value, decoded))
             return false;
@@ -449,14 +475,14 @@ static bool rfc2047_decodeParsed(const std::string& charset,
             else 
                 temp += decoded[pos];
         decoded = temp;
-        DPRINT((stderr, "FromQP: [%s]\n", decoded.c_str()));
+        DPRINT("rfc2047_decodeParsed: fromQP: [" << decoded << "]\n");
     } else {
-        DPRINT((stderr, "Bad encoding [%s]\n", encoding.c_str()));
+        DPRINT("rfc2047_decodeParsed: bad encoding [" << encoding << "]\n");
         return false;
     }
 
     if (!transcode(decoded, utf8, charset, cstr_utf8)) {
-        DPRINT((stderr, "Transcode failed\n"));
+        DPRINT("rfc2047_decodeParsed: transcode failed\n");
         return false;
     }
     return true;
@@ -474,11 +500,11 @@ typedef enum  {rfc2047ready, rfc2047open_eq,
 
 bool rfc2047_decode(const std::string& in, std::string &out) 
 {
-    DPRINT((stderr, "rfc2047_decode: [%s]\n", in.c_str()));
+    DPRINT("rfc2047_decode: [" << in << "]\n");
 
     Rfc2047States state = rfc2047ready;
     string encoding, charset, value, utf8;
-
+    
     out.clear();
 
     for (string::size_type ii = 0; ii < in.length(); ii++) {
@@ -486,29 +512,27 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         switch (state) {
         case rfc2047ready: 
         {
-            DPRINT((stderr, "STATE: ready, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: ready, ch " << ch << '\n');
             switch (ch) {
-                // Whitespace: stay ready
-            case ' ': case '\t': value += ch;break;
-                // '=' -> forward to next state
-            case '=': state = rfc2047open_eq; break;
-                DPRINT((stderr, "STATE: open_eq\n"));
-                // Other: go back to sleep
-            default: value += ch; state = rfc2047ready;
+            case '=': // -> next state
+                state = rfc2047open_eq;
+                DPRINT("rfc2047_decode: STATE: open_eq\n");
+                break;
+            default: // Any other: stay in initial state
+                value += ch; state = rfc2047ready; break;
             }
         }
         break;
         case rfc2047open_eq: 
         {
-            DPRINT((stderr, "STATE: open_eq, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: open_eq, ch " << ch << '\n');
             switch (ch) {
             case '?': 
             {
-                // Transcode current (unencoded part) value:
-                // we sometimes find 8-bit chars in
-                // there. Interpret as Iso8859.
+                // Transcode current (unencoded part) value: we sometimes find 8-bit chars in
+                // there. Interpret as CP1252.
                 if (value.length() > 0) {
-                    transcode(value, utf8, "ISO-8859-1", cstr_utf8);
+                    utf8OrCp1252(value, utf8);
                     out += utf8;
                     value.clear();
                 }
@@ -521,7 +545,7 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         break;
         case rfc2047charset: 
         {
-            DPRINT((stderr, "STATE: charset, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: charset, ch " << ch << '\n');
             switch (ch) {
             case '?': state = rfc2047encoding; break;
             default: charset += ch; break;
@@ -530,7 +554,7 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         break;
         case rfc2047encoding: 
         {
-            DPRINT((stderr, "STATE: encoding, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: encoding, ch " << ch << '\n');
             switch (ch) {
             case '?': state = rfc2047value; break;
             default: encoding += ch; break;
@@ -539,7 +563,7 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         break;
         case rfc2047value: 
         {
-            DPRINT((stderr, "STATE: value, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: value, ch " << ch << '\n');
             switch (ch) {
             case '?': state = rfc2047close_q; break;
             default: value += ch;break;
@@ -548,15 +572,15 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         break;
         case rfc2047close_q: 
         {
-            DPRINT((stderr, "STATE: close_q, ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: close_q, ch " << ch << '\n');
             switch (ch) {
             case '=': 
             {
-                DPRINT((stderr, "End of encoded area. Charset %s, Encoding %s\n", charset.c_str(), encoding.c_str()));
+                DPRINT("rfc2047_decode: end of encoded area. Charset " << charset <<
+                       " encoding " << encoding << "\n");
                 string utf8;
                 state = rfc2047ready; 
-                if (!rfc2047_decodeParsed(charset, encoding, value, 
-                                          utf8)) {
+                if (!rfc2047_decodeParsed(charset, encoding, value, utf8)) {
                     return false;
                 }
                 out += utf8;
@@ -570,28 +594,24 @@ bool rfc2047_decode(const std::string& in, std::string &out)
         }
         break;
         default: // ??
-            DPRINT((stderr, "STATE: default ?? ch %c\n", ch));
+            DPRINT("rfc2047_decode: STATE: default ?? ch " << ch << '\n');
             return false;
         }
     }
 
-    if (value.length() > 0) {
-        transcode(value, utf8, "CP1252", cstr_utf8);
-        out += utf8;
-        value.clear();
-    }
-    if (state != rfc2047ready) 
+    if (state != rfc2047ready) {
+        // Bad format. Just try to decode and return the result
+        utf8OrCp1252(in, out);
         return false;
+    }
+    if (value.length() > 0) {
+        // Residual (could be whole input)
+        utf8OrCp1252(value, utf8);
+        out += utf8;
+    }
     return true;
 }
 
-#define DEBUGDATE 0
-#if DEBUGDATE
-#define DATEDEB(X) fprintf X
-#else
-#define DATEDEB(X)
-#endif
-
 // Convert rfc822 date to unix time. A date string normally looks like:
 //  Mon, 3 Jul 2006 09:51:58 +0200
 // But there are many close common variations
@@ -604,8 +624,7 @@ time_t rfc2822DateToUxTime(const string& dt)
     string::size_type idx;
     if ((idx = dt.find_first_of(",")) != string::npos) {
         if (idx == dt.length() - 1) {
-            DATEDEB((stderr, "Bad rfc822 date format (short1): [%s]\n", 
-                     dt.c_str()));
+            DATEDEB("Bad rfc822 date format (short1): [" << dt << "]\n");
             return (time_t)-1;
         }
         string date = dt.substr(idx+1);
@@ -627,15 +646,14 @@ time_t rfc2822DateToUxTime(const string& dt)
     }
 
 #if DEBUGDATE
-    for (list<string>::iterator it = toks.begin(); it != toks.end(); it++) {
-        DATEDEB((stderr, "[%s] ", it->c_str()));
+    for (const auto& tok : toks) {
+        DATEDEB("[" << tok << "] ");
     }
-    DATEDEB((stderr, "\n"));
+    DATEDEB("\n");
 #endif
 
     if (toks.size() < 6) {
-        DATEDEB((stderr, "Bad rfc822 date format (toks cnt): [%s]\n", 
-                 dt.c_str()));
+        DATEDEB("Bad rfc822 date format (toks cnt): [" << dt << "]\n");
         return (time_t)-1;
     }
 
@@ -670,8 +688,7 @@ time_t rfc2822DateToUxTime(const string& dt)
         (*it == "Oct" || *it == "October") tm.tm_mon = 9; else if
         (*it == "Nov" || *it == "November") tm.tm_mon = 10; else if
         (*it == "Dec" || *it == "December") tm.tm_mon = 11; else {
-        DATEDEB((stderr, "Bad rfc822 date format (month): [%s]\n", 
-                 dt.c_str()));
+        DATEDEB("Bad rfc822 date format (month): [" << dt << "]\n");
         return (time_t)-1;
     }
     it++;
@@ -698,15 +715,14 @@ time_t rfc2822DateToUxTime(const string& dt)
     // Timezone is supposed to be either +-XYZT or a zone name
     int zonesecs = 0;
     if (it->length() < 1) {
-        DATEDEB((stderr, "Bad rfc822 date format (zlen): [%s]\n", dt.c_str()));
+        DATEDEB("Bad rfc822 date format (zlen): [" << dt << "]\n");
         return (time_t)-1;
     }
     if (it->at(0) == '-' || it->at(0) == '+') {
         // Note that +xy:zt (instead of +xyzt) sometimes happen, we
         // may want to process it one day
         if (it->length() < 5) {
-            DATEDEB((stderr, "Bad rfc822 date format (zlen1): [%s]\n", 
-                     dt.c_str()));
+            DATEDEB("Bad rfc822 date format (zlen1): [" << dt << "]\n");
             goto nozone;
         }
         zonesecs = 3600*((it->at(1)-'0') * 10 + it->at(2)-'0')+ 
@@ -738,14 +754,13 @@ time_t rfc2822DateToUxTime(const string& dt)
         else if (*it == "IST") hours= -5; else if (*it == "WET") hours= 0; 
         else if (*it == "MET") hours= -1; 
         else {
-            DATEDEB((stderr, "Bad rfc822 date format (zname): [%s]\n", 
-                     dt.c_str()));
+            DATEDEB("Bad rfc822 date format (zname): [" << dt << "]\n");
             // Forget tz
             goto nozone;
         }
         zonesecs = 3600 * hours;
     }
-    DATEDEB((stderr, "Tz: [%s] -> %d\n", it->c_str(), zonesecs));
+    DATEDEB("Tz: [" << *it << "] -> " << zonesecs << "\n");
 nozone:
 
     // Compute the UTC Unix time value
@@ -754,21 +769,19 @@ nozone:
 #else
     // No timegm on Sun. Use mktime, then correct for local timezone
     time_t tim = mktime(&tm);
-    // altzone and timezone hold the difference in seconds between UTC
-    // and local. They are negative for places east of greenwich
+    // altzone and timezone hold the difference in seconds between UTC and local. They are negative
+    // for places east of greenwich
     // 
-    // mktime takes our buffer to be local time, so it adds timezone
-    // to the conversion result (if timezone is < 0 it's currently
-    // earlier in greenwhich). 
+    // mktime takes our buffer to be local time, so it adds timezone to the conversion result (if
+    // timezone is < 0 it's currently earlier in greenwhich).
     //
-    // We have to substract it back (hey! hopefully! maybe we have to
-    // add it). Who can really know?
+    // We have to substract it back (hey! hopefully! maybe we have to add it). Who can really know?
     tim -= timezone;
 #endif
 
     // And add in the correction from the email's Tz
     tim += zonesecs;
 
-    DATEDEB((stderr, "Date: %s  uxtime %ld \n", ctime(&tim), tim));
+    DATEDEB("Date: " << ctime(&tim) << " uxtime " << tim << '\n');
     return tim;
 }
