@@ -18,13 +18,17 @@
 #ifndef _SMALLUT_H_INCLUDED_
 #define _SMALLUT_H_INCLUDED_
 
-#include <stdint.h>
-#include <time.h>
+#ifdef __MINGW32__
+#define _POSIX_C_SOURCE 200809L
+#endif
+
+#include <cstdint>
+#include <ctime>
+#include <functional>
+#include <map>
+#include <memory>
 #include <string>
 #include <vector>
-#include <map>
-#include <functional>
-#include <memory>
 
 struct tm;
 
@@ -44,7 +48,7 @@ void smallut_init_mt();
 #define MAX(A,B) (((A)>(B)) ? (A) : (B))
 #endif
 #ifndef deleteZ
-#define deleteZ(X) {delete X;X = nullptr;}
+#define deleteZ(X) do {delete X;X = nullptr;} while(0)
 #endif
 #ifndef PRETEND_USE
 #define PRETEND_USE(var) ((void)(var))
@@ -66,7 +70,7 @@ struct StringIcmpPred {
     explicit StringIcmpPred(const std::string& s1)
         : m_s1(s1) {
     }
-    bool operator()(const std::string& s2) {
+    bool operator()(const std::string& s2) const {
         return stringicmp(m_s1, s2) == 0;
     }
     const std::string& m_s1;
@@ -82,29 +86,19 @@ extern std::string stringtolower(const std::string& io);
 extern void stringtoupper(std::string& io);
 extern std::string stringtoupper(const std::string& io);
 extern bool beginswith(const std::string& b, const std::string& sml);
+extern bool endswith(const std::string& bg, const std::string& sml);
 
-// Parse date interval specifier into pair of y,m,d dates.  The format
-// for the time interval is based on a subset of iso 8601 with
-// the addition of open intervals, and removal of all time indications.
-// 'P' is the Period indicator, it's followed by a length in
-// years/months/days (or any subset thereof)
-// Dates: YYYY-MM-DD YYYY-MM YYYY
-// Periods: P[nY][nM][nD] where n is an integer value.
-// At least one of YMD must be specified
-// The separator for the interval is /. Interval examples
-// YYYY/ (from YYYY) YYYY-MM-DD/P3Y (3 years after date) etc.
-// This returns a pair of y,m,d dates.
-struct DateInterval {
-    int y1;
-    int m1;
-    int d1;
-    int y2;
-    int m2;
-    int d2;
-};
-extern bool parsedateinterval(const std::string& s, DateInterval *di);
-extern int monthdays(int mon, int year);
-
+#ifdef _WIN32
+// Conversion between utf-8 and wide char file names.
+bool wchartoutf8(const wchar_t *in, std::string& out, int len = 0);
+std::string wchartoutf8(const wchar_t *in, int len = 0);
+bool utf8towchar(const std::string& in, wchar_t *out, int obytescap);
+std::unique_ptr<wchar_t[]> utf8towchar(const std::string& in);
+#define strcasecmp _stricmp
+#define strncasecmp _strnicmp
+#define localtime_r(a,b) localtime_s(b,a)
+#define strtok_r strtok_s
+#endif // _WIN32
 
 /** Note for all templated functions:
  * By default, smallut.cpp has explicit instantiations for common
@@ -139,10 +133,10 @@ template <class T> std::string stringsToString(const T& tokens);
  * " inside tokens is escaped as "" ([word "quote"] =>["word ""quote"""]
  * See instantiation note above.
  */
-template <class T> void stringsToCSV(const T& tokens, std::string& s, char sep = ',');
+template <class T> std::string stringsToCSV(const T& tokens, char sep = ',');
 
 /** Find longest common prefix for bunch of strings */
-template <class T> std::string commonprefix(const T& values);
+template <class T> std::string commonprefix(const T& values, bool aspaths = false);
 
 /**
  * Split input string. No handling of quoting.
@@ -157,6 +151,10 @@ extern void stringSplitString(const std::string& str,
                               std::vector<std::string>& tokens,
                               const std::string& sep);
 
+/** Join strings with string separator. No handling of quoting. */
+extern std::string tokensToString(const std::vector<std::string>& tokens,
+                                  const std::string& sep = " ");
+
 /** Convert string to boolean */
 extern bool stringToBool(const std::string& s);
 
@@ -173,8 +171,7 @@ extern std::string escapeHtml(const std::string& in);
 extern std::string makeCString(const std::string& in);
 
 /** Replace some chars with spaces (ie: newline chars). */
-extern std::string neutchars(const std::string& str, const std::string& chars,
-                             char rep = ' ');
+extern std::string neutchars(const std::string& str, const std::string& chars, char rep = ' ');
 extern void neutchars(const std::string& str, std::string& out,
                       const std::string& chars, char rep = ' ');
 
@@ -182,15 +179,9 @@ extern void neutchars(const std::string& str, std::string& out,
  *  quote with double-quotes and escape $`\ */
 extern std::string escapeShell(const std::string& in);
 
-/** Truncate a string to a given maxlength, avoiding cutting off midword
- *  if reasonably possible. */
+/** Truncate a string to a given maxlength, avoiding cutting off midword if reasonably possible. */
 extern std::string truncate_to_word(const std::string& input, std::string::size_type maxlen);
 
-void ulltodecstr(uint64_t val, std::string& buf);
-void lltodecstr(int64_t val, std::string& buf);
-std::string lltodecstr(int64_t val);
-std::string ulltodecstr(uint64_t val);
-
 /** Convert byte count into unit (KB/MB...) appropriate for display */
 std::string displayableBytes(int64_t size);
 
@@ -200,10 +191,11 @@ std::string breakIntoLines(const std::string& in, unsigned int ll = 100, unsigne
 /** Small utility to substitute printf-like percents cmds in a string */
 bool pcSubst(const std::string& in, std::string& out, const std::map<char, std::string>& subs);
 /** Substitute printf-like percents and also %(key) */
-bool pcSubst(const std::string& in, std::string& out,
-             const std::map<std::string, std::string>& subs);
+bool pcSubst(
+    const std::string& in, std::string& out, const std::map<std::string, std::string>& subs);
 /** Substitute printf-like percents and %(nm), using result of function call */
-bool pcSubst(const std::string& i, std::string& o, const std::function<std::string(const std::string&)>&);
+bool pcSubst(
+    const std::string& i, std::string& o, const std::function<std::string(const std::string&)>&);
 
 /** Stupid little smart buffer handler avoiding value-initialization when not needed (e.g. for using
     as read buffer **/
@@ -221,12 +213,11 @@ public:
 /** Append system error message */
 void catstrerror(std::string *reason, const char *what, int _errno);
 
-/** Portable timegm. MS C has _mkgmtime, but there is a bug in Gminw which
- * makes it inaccessible */
+/** Portable timegm. MS C has _mkgmtime, but there is a bug in Gminw which makes it inaccessible */
 time_t portable_timegm(struct tm *tm);
 
 inline void leftzeropad(std::string &s, unsigned len) {
-    if (s.length() && s.length() < len) {
+    if (!s.empty() && s.length() < len) {
         s = s.insert(0, len - s.length(), '0');
     }
 }
@@ -267,6 +258,11 @@ private:
 };
 #endif // SMALLUT_NO_REGEX
 
+inline void copybits(unsigned int& to, unsigned int from, unsigned int mask)
+{
+    to = (to & ~mask) | (from & mask);
+}
+
 /// Utilities for printing names for defined values (Ex: O_RDONLY->"O_RDONLY")
 
 /// Entries for the descriptive table
@@ -288,8 +284,16 @@ extern std::string flagsToString(const std::vector<CharFlags>&, unsigned int val
 /// Translate a value into a name
 extern std::string valToString(const std::vector<CharFlags>&, unsigned int val);
 
-/// Decode percent-encoded URL
-extern std::string url_decode(const std::string&);
+/// Decode percent-encoded string
+extern std::string pc_decode(const std::string&);
+
+/// Parse HTTP range header value into a vector of offset pairs. -1 is used as a placeholder
+/// wherever a part of a range is absent: either for a missing end or for a suffix range (absent
+/// start meaning count from the end).
+bool parseHTTPRanges(const std::string& ranges, std::vector<std::pair<int64_t, int64_t>>& oranges);
+
+void millisleep(int millis);
+
 
 } // End namespace MedocUtils
 
