@@ -20,8 +20,10 @@
 #ifdef UTF8ITER_CHECK
 #include "assert.h"
 #endif
-#include <string>
+
+#include <cstddef>
 #include <cstdint>
+#include <string>
 
 /** 
  * A small helper class to iterate over utf8 strings. This is not an
@@ -167,7 +169,7 @@ private:
 
     // Update current char length in object state, check
     // for errors
-    inline void update_cl() {
+    void update_cl() {
         m_cl = 0;
         if (m_pos >= m_sp->length())
             return;
@@ -184,7 +186,7 @@ private:
         }
     }
 
-    inline bool checkvalidat(std::string::size_type p, int l) const {
+    bool checkvalidat(std::string::size_type p, int l) const {
         switch (l) {
         case 1: 
             return uint8_t((*m_sp)[p]) < 128;
@@ -208,7 +210,7 @@ private:
     }
 
     // Get character byte length at specified position. Returns 0 for error.
-    inline int get_cl(std::string::size_type p) const {
+    int get_cl(std::string::size_type p) const {
         unsigned int z = uint8_t((*m_sp)[p]);
         if (z <= 127) {
             return 1;
@@ -227,7 +229,7 @@ private:
     }
 
     // Compute value at given position. No error checking.
-    inline unsigned int getvalueat(std::string::size_type p, int l) const {
+    unsigned int getvalueat(std::string::size_type p, int l) const {
         switch (l) {
         case 1: 
 #ifdef UTF8ITER_CHECK
@@ -298,15 +300,13 @@ size_t utf8len(const std::string& s);
 /** Return number of bytes for Unicode character */
 inline int utf8codepointsize(uint32_t codepoint)
 {
-    if (codepoint <= 0x7F) {
+    if (codepoint <= 0x7F)
         return 1;
-    } else if (codepoint <= 0x7FF) {
+    if (codepoint <= 0x7FF)
         return 2;
-    } else if (codepoint < 0xFFFF) {
+    if (codepoint < 0xFFFF)
         return 3;
-    } else {
-        return 4;
-    }
+    return 4;
 }
 
 /** @brief Check and possibly fix string by replacing badly encoded
